@@ -26,9 +26,9 @@ schemes = {
             'image': lambda x: get_yandex_profile_pic(x['owner']['avatarHash']),
             'links': lambda x: [link for links in x['profiles'] for link in links['addresses']],
             'is_verified': lambda x: x['verified'],
-            'liked_albums': lambda x: x['counts']['likedAlbums'],
-            'liked_artists': lambda x: x['counts']['likedArtists'],
-            'has_tracks': lambda x: x['hasTracks'],
+            'liked_albums': lambda x: x['counts'].get('likedAlbums'),
+            'liked_artists': lambda x: x['counts'].get('likedArtists'),
+            'has_tracks': lambda x: x.get('hasTracks'),
         }
     },
     'Yandex Q (Znatoki) user profile': {
@@ -198,7 +198,7 @@ schemes = {
             'fullname': lambda x: x.get('title'),
             'image': lambda x: x.get('logo'),
             'bio': lambda x: x.get('description'),
-            'messenger_guid': lambda x: x.get('messengerGuid'),
+            'yandex_messenger_guid': lambda x: x.get('messengerGuid'),
             'links': lambda x: x.get('socialLinks'),
             'type': lambda x: x.get('type'),
             'comments_count': lambda x: x.get('userCommentsCount'),
@@ -207,6 +207,44 @@ schemes = {
             'follower_count': lambda x: x.get('subscriptions'),
         },
     },
+    'Yandex messenger search API': {
+        'flags': ['messages', 'matches', 'users_and_chats'],
+        'regex': r'^(.+)$',
+        'extract_json': True,
+        'transforms': [
+            json.loads,
+            lambda x: x['data']['users_and_chats']['items'],
+            lambda x: x if len(x) == 1 else list(filter(lambda y: y['matches'].get('nickname'), x)),
+            lambda x: x[0] if x else {},
+            json.dumps,
+        ],
+        'fields': {
+            'fullname': lambda x: x['data']['display_name'],
+            'username': lambda x: x['matches'].get('nickname', [None])[0],
+            'yandex_messenger_guid': lambda x: x['data']['guid'],
+            'registration_status': lambda x: x['data']['registration_status'],
+            'image': lambda x: get_yandex_profile_pic(x['data'].get('avatar_id')),
+            'yandex_phone_id': lambda x: x['data'].get('phone_id'),
+            'yandex_uid': lambda x: x['data'].get('uid'),
+        },
+    },
+    'Yandex messenger profile API': {
+        'flags': ['guid', 'registration_status', 'contacts'],
+        'regex': r'^(.+)$',
+        'extract_json': True,
+        'transforms': [
+            json.loads,
+            lambda x: x['data']['users'][0],
+            json.dumps,
+        ],
+        'fields': {
+            'fullname': lambda x: x['display_name'],
+            'yandex_messenger_guid': lambda x: x['guid'],
+            'registration_status': lambda x: x['registration_status'],
+            'image': lambda x: get_yandex_profile_pic(x.get('avatar_id')),
+            'yandex_phone_id': lambda x: x.get('phone_id'),
+        },
+    },
     'Yandex Bugbounty user profile': {
         'flags': ['yandex_bug_bounty_terms_conditions', 'user__pic'],
         'regex': r'upics\.yandex\.net\/(?P<yandex_uid>\d+)[\s\S]+<span>(?P<firstname>.+?)<\/span>\s+<em>(?P<username>.+?)<\/em>([\s\S]+?class="link">(?P<email>.+?)<\/a>)?([\s\S]+?<a href="(?P<url>.+?)" target="_blank" class="link link_social">)?',
